(function() {

    var Dashboard = {
        init : function() {

            this.initCharts();

            var date = new Date();
            date.setHours(date.getHours() - 1);

            var start = DateUtil.format(date, 'yyyy-MM-dd HH:mm:ss');
            var end = undefined;

            Dashboard.loadTarget(targetId, Dashboard.renderTarget);
            Dashboard.loadStatistics(targetId, start, end, Dashboard.renderCharts);
        },

        initCharts : function() {
            $.charts.buildAreaAndLine('#heap-chart', 'Heap memory', function(v) {
                return Size.to(v);
            });
            $.charts.buildAreaAndLine('#thread-chart', 'Threads');
            $.charts.buildAreaAndLine('#cpu-chart', 'Cpu used', function(v) {
                return v + '%';
            });
        },

        loadTarget : function(targetId, fn) {
            $.getJSON(ctx + '/target/findOne', {
                targetId : targetId
            }, function(json) {
                if (json.succeed) {
                    fn (json.data);
                } else {
                    Toast.danger(json.msg);
                }
            });
        },

        loadStatistics : function(targetId, start, end, fn) {
            $.getJSON(ctx + '/statistics/find', {
                targetId : targetId,
                start : start,
                end : end
            }, function(json) {
                if (json.succeed) {
                    fn(json.data);
                } else {
                    Toast.danger(json.msg);
                }
            });
        },

        renderTarget : function(data) {
            $('#name').text(data.name);
            $('#url').text(data.url);
        },

        renderCharts : function(data) {
            var max = [];
            var used = [];
            var threads = [];
            var cpu = [];
            for (var i = 0; i < data.length; i++) {
                var item = data[i];
                used.push({ x : item.time, y : item.heapMemory ? item.heapMemory.used : 0 });
                max.push({ x : item.time, y : item.heapMemory ? item.heapMemory.max : 0 });
                cpu.push({ x : item.time, y : item.systemLoadAverage ? item.systemLoadAverage : 0 });

                threads.push({ x : item.time, y : item.thread ? item.thread.thread : 0 });
            }

            $('#heap-chart').highcharts().addSeries({name : 'used', type : 'area', data : used});
            $('#heap-chart').highcharts().addSeries({name : 'max', type : 'line', data : max});
            $('#thread-chart').highcharts().addSeries({name : 'thread', type : 'line', data : threads});
            $('#cpu-chart').highcharts().addSeries({name : 'cpu used', type : 'line', data : cpu});
        }
    }

    $(function() {
        Dashboard.init();
    });

})(jQuery);