Highcharts.setOptions({ global: { useUTC: false } });

(function($) {
	
	'use strict';
	
	$.charts = {
		init : function() {
			
		},
		
		buildLine : function(regx, title, subtitle, yAxisTitle, yAxisUnit, series, height, max) {
			$(regx).highcharts({
				chart: {
					type : 'line',
					height : !height ? 300 : height,
					zoomType: 'x',
					spacingRight: 20,
					borderRadius: 0,
				},
				title: {
					text: title
				},
				subtitle: {
					text: subtitle
				},
				credits: {
					enabled: false
				},
				xAxis: {
					type: 'datetime',
				},
				yAxis: {
					min: 0,
					max : max,
					title: {
						text: yAxisTitle
					}
				},
				exporting: {
					enabled: false
				},
				tooltip: {
					xDateFormat: '%Y-%m-%d',
					shared: true,
					crosshairs: true,
				},
				plotOptions: {
		            line: {
		                dataLabels: {
		                    enabled: true
		                }
		            }
		        },
		        series: series
			});
		},

		buildAreaAndLine : function(regx, title, yFormatter) {
			$(regx).highcharts({
				chart: {
					height : 300,
	                zoomType: 'x',
	                spacingRight: 20,
		            borderRadius: 0,
	            },
	            title: {
	                text: title
	            },
	            credits: {
		        	enabled: false
		        },
	            xAxis: {
	                type: 'datetime'
	            },
	            yAxis: {
		        	min: 0,
	                labels: {
		                formatter: function() {
		                    return yFormatter ? yFormatter(this.value) : this.value;
		                }
		            }
	            },
	            plotOptions: {
	                area: {
	                    fillColor: {
	                        linearGradient: { x1: 0, y1: 0, x2: 0, y2: 1},
	                        stops: [
	                            [0, Highcharts.getOptions().colors[0]],
	                            [1, Highcharts.Color(Highcharts.getOptions().colors[0]).setOpacity(0).get('rgba')]
	                        ]
	                    },
	                    lineWidth: 1,
	                    marker: {
	                        enabled: false
	                    },
	                    shadow: false,
	                    states: {
	                        hover: {
	                            lineWidth: 1
	                        }
	                    },
	                    threshold: null
	                },
	                line: {
		        		lineWidth: 1,
		        		states: {
	                        hover: {
	                            lineWidth: 1
	                        }
	                    },
		            	marker: {
		            		radius: 1
		            	}
		        	},
		        	series: {
		        		turboThreshold: 0
		        	}
	            },
	            exporting: {
		            enabled: false
		        },
				tooltip: {
					xDateFormat: '%Y-%m-%d %H:%M:%S',
					shared: true,
					crosshairs: true,
                    pointFormatter: function() {
                        return this.series.name + ": " + (yFormatter ? yFormatter(this.y) : this.y) + "<br />";
                    }
				},
	            series: []
		    });
		},
		
		buildPie: function(regx, title, series) {
			$(regx).highcharts({
				chart: {
					height : 300,
					plotBackgroundColor: null,
					plotBorderWidth: null,
					plotShadow: false
				},
				title: {
					text: title
				},
				credits: {
					enabled: false
				},
				tooltip: {
					pointFormat: '{series.name}: <b>{point.y}</b>'
				},
				plotOptions: {
	                pie: {
	                    allowPointSelect: true,
	                    cursor: 'pointer',
	                    dataLabels: {
	                        enabled: false
	                    },
	                    showInLegend: true
	                }
	            },
				series: series
			});
		}
	}
	
})(jQuery);